==> grizzly-framework-1.9.35-sources.jar: com/sun/grizzly/async/AsyncReadCondition.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2010 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.grizzly.async;

import java.net.SocketAddress;
import java.nio.ByteBuffer;
import java.nio.channels.SelectionKey;

/**
 * Interface represents condition, which will be checked when 
 * {@link AsyncQueueReader} was able to read new portion of data from 
 * {@link SelectableChannel}, whoch is associated with a
 * {@link SelectionKey}. Custom condition code could decide whether read data
 * is enough to call <code>AsyncReadCallbackHandler.onReadCompleted()</code> or
 * more data is expected.
 * 
 * @author Alexey Stashok
 */
public interface AsyncReadCondition {
    /**
     * Method checks, whether data, which was read to the {@link ByteBuffer},
     * is read completely, or custom code expects more data.
     * 
     * @param key {@link SelectionKey}
     * @param srcAddress {@link SocketAddress} remote address data was read from
     * @param buffer {@link ByteBuffer} data was read to
     * @return true, if data reading is completed, false - if mora data is expected
     */
    public boolean checkAsyncReadCompleted(SelectionKey key, 
            SocketAddress srcAddress, ByteBuffer buffer);
}

==> grizzly-framework-1.9.65-sources.jar: com/sun/grizzly/async/AsyncReadCondition.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.grizzly.async;

import java.net.SocketAddress;
import java.nio.ByteBuffer;
import java.nio.channels.SelectionKey;

/**
 * Interface represents condition, which will be checked when 
 * {@link AsyncQueueReader} was able to read new portion of data from 
 * {@link java.nio.channels.SelectableChannel}, which is associated with a
 * {@link SelectionKey}. Custom condition code could decide whether read data
 * is enough to call <code>AsyncReadCallbackHandler.onReadCompleted()</code> or
 * more data is expected.
 * 
 * @author Alexey Stashok
 */
public interface AsyncReadCondition {
    /**
     * Method checks, whether data, which was read to the {@link ByteBuffer},
     * is read completely, or custom code expects more data.
     * 
     * @param key {@link SelectionKey}
     * @param srcAddress {@link SocketAddress} remote address data was read from
     * @param buffer {@link ByteBuffer} data was read to
     * @return true, if data reading is completed, false - if mora data is expected
     */
    public boolean checkAsyncReadCompleted(SelectionKey key, 
            SocketAddress srcAddress, ByteBuffer buffer);
}
